@@ -73,4 +73,4 @@ def test_sent2words():
     words = vectorizer.sent2words(sentences=sentences, remove_stop_words=['not'])
     assert words == [['alice', 'wonderland'], ['alice', 'not', 'wonderland']]
 
-test_sent2vec_bert_02()
\ No newline at end of file
+test_sent2vec_w2v()
\ No newline at end of file
